﻿using Protocols;
using Protocols.GameBox;
using Redis;
using ServerLib;
using System;
using System.Collections.Generic;
using System.Threading.Tasks;
using Utility;

namespace ServerLib
{
    public static class EnumHelp
    {
        /// <summary>
        /// 增加多个数据
        /// </summary>
        /// <typeparam name="T"></typeparam>
        /// <param name="lstValues"></param>
        public static List<EGameType> GetList<EGameType>()
        {
            var lstEnums = new List<EGameType>();
            foreach (var item in Enum.GetValues(typeof(EGameType)))
            {
                lstEnums.Add((EGameType)item);
            }
            return lstEnums;
        }
    }

    public static class OtherExtension
    {
        public static string GetKey(this EGameType gameType)
        {
            //游戏类型
            if (gameType == EGameType.FlyBirdOnline)
            {
                return RedisName.flybird_online;
            }
            else if (gameType == EGameType.TetrisOnline)
            {
                return RedisName.tetris_online;
            }
            else if (gameType == EGameType.GobangOnline)
            {
                return RedisName.gobang_online;
            }
            else if (gameType == EGameType.LandlordOnline)
            {
                return RedisName.landlord_online;
            }
            else if (gameType == EGameType.ChineseChessOnline)
            {
                return RedisName.chinesechess_online;
            }
            else if (gameType == EGameType.LinkOnline)
            {
                return RedisName.link_online;
            }
            else if (gameType == EGameType.StarlistOnline)
            {
                return RedisName.starlist_online;
            }
            else if (gameType == EGameType.FingerOnline)
            {
                return RedisName.finger_online;
            }
            else if (gameType == EGameType.DiceKing)
            {
                return RedisName.dice_king_online;
            }
            else if (gameType == EGameType.MJQueShen)
            {
                return RedisName.mj_queshen_online;
            }
            else if (gameType == EGameType.MJXueLiu)
            {
                return RedisName.mj_xueliu_online;
            }
            else if (gameType == EGameType.ThreeLandLord)
            {
                return RedisName.three_landlord_online;
            }
            else if (gameType == EGameType.DragonTigerFightOnline)
            {
                return RedisName.dragontigerfight_online;
            }
            else if (gameType == EGameType.RedpacketDemining)
            {
                return RedisName.redpacketdemining;
            }

            return "defaultgame";
        }

        /// <summary>
        /// 获取游戏名称
        /// </summary>
        /// <param name="gameType"></param>
        /// <returns></returns>
        public static EGameName GetGameName(this EGameType gameType)
        {
            //游戏类型
            if (gameType == EGameType.FlyBirdOnline)
            {
                return EGameName.FlyBird;
            }
            else if (gameType == EGameType.TetrisOnline)
            {
                return EGameName.Tetris;
            }
            else if (gameType == EGameType.GobangOnline)
            {
                return EGameName.Gobang;
            }
            else if (gameType == EGameType.LandlordOnline)
            {
                return EGameName.Landlord;
            }
            else if (gameType == EGameType.ChineseChessOnline)
            {
                return EGameName.ChineseChess;
            }
            else if (gameType == EGameType.LinkOnline)
            {
                return EGameName.Link;
            }
            else if (gameType == EGameType.StarlistOnline)
            {
                return EGameName.Starlist;
            }
            else if (gameType == EGameType.FingerOnline)
            {
                return EGameName.Finger;
            }
            else if (gameType == EGameType.MJQueShen)
            {
                return EGameName.MJQueShen;
            }
            else if (gameType == EGameType.MJXueLiu)
            {
                return EGameName.MJXueLiu;
            }
            else if (gameType == EGameType.ThreeLandLord)
            {
                return EGameName.ThreeLandlord;
            }
            else if (gameType == EGameType.DiceKing)
            {
                return EGameName.DiceKing;
            }
            else if (gameType == EGameType.DragonTigerFightOnline)
            {
                return EGameName.DragonTigerFight;
            }
            else if (gameType == EGameType.RedpacketDemining)
            {
                return EGameName.RedpacketDemining;
            }

            return EGameName.Null;
        }

        /// <summary>
        /// 获取游戏模式
        /// </summary>
        /// <param name="gameType"></param>
        /// <returns></returns>
        public static EGameNetType GetGameNetType(this EGameType gameType)
        {
            if (gameType == EGameType.FlyBirdOnline ||
                gameType == EGameType.TetrisOnline ||
                gameType == EGameType.GobangOnline ||
                gameType == EGameType.LandlordOnline ||
                gameType == EGameType.ChineseChessOnline ||
                gameType == EGameType.LinkOnline ||
                gameType == EGameType.StarlistOnline ||
                gameType == EGameType.FingerOnline ||
                gameType == EGameType.DiceKing ||
                gameType == EGameType.MJQueShen ||
                gameType == EGameType.MJXueLiu ||
                gameType == EGameType.ThreeLandLord ||
                gameType == EGameType.RedpacketDemining ||
                gameType == EGameType.DragonTigerFightOnline)
            {
                return EGameNetType.Online;

            }

            return EGameNetType.Null;
        }
        
        public static string GetGameTypeStr(this EGameType gameType)
        {
            if (gameType == EGameType.FlyBirdOnline)
            {
                return "蠢鸟飞飞多人模式";
            }
            if (gameType == EGameType.TetrisOnline)
            {
                return "俄罗斯方块多人模式";
            }
            if (gameType == EGameType.GobangOnline)
            {
                return "五子棋多人模式";
            }
            if (gameType == EGameType.LandlordOnline)
            {
                return "二人斗地主";
            }
            if (gameType == EGameType.ChineseChessOnline)
            {
                return "中国象棋多人模式";
            }
            if (gameType == EGameType.LinkOnline)
            {
                return "水果连萌多人模式";
            }
            if (gameType == EGameType.StarlistOnline)
            {
                return "消星星多人模式";
            }
            if (gameType == EGameType.FingerOnline)
            {
                return "石头剪刀布多人模式";
            }
            return "";
        }
    }
}